﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerController : MonoBehaviour {

	public Sprite nothingSprite;
	public Sprite cableSprite;

	public float movementSpeed = 5f;

	private Rigidbody2D _rigidbody2D;
	private SpriteRenderer _spriteRenderer;

	public Station LinkedStation {
		get; private set;
	}

	private void Awake() {
		_rigidbody2D = GetComponent<Rigidbody2D>();
		_spriteRenderer = GetComponent<SpriteRenderer>();
	}

	// Update is called once per frame
	void Update() {
		float x, y;

		x = Input.GetAxis("Horizontal");
		y = Input.GetAxis("Vertical");

		_rigidbody2D.MovePosition(_rigidbody2D.position + (new Vector2(x, y) * Time.deltaTime * movementSpeed));

		if (Input.GetButtonDown("Fire1")) {
			UseStation();
		}

		if (Input.GetButtonDown("Jump")) {
			DropStation();
		}
	}

	private void OnTriggerEnter2D(Collider2D collision) {
		Station station = collision.gameObject.GetComponent<Station>();

		if (station != null) {
			if (LinkedStation != null) {
				LinkedStation.ToggleSelection(false);
			}

			LinkedStation = station;
			_spriteRenderer.sprite = cableSprite;

			LinkedStation.ToggleSelection(true);

			return;
		}

		Lamp lamp = collision.gameObject.GetComponent<Lamp>();

		if (lamp != null && LinkedStation != null) {
			lamp.ConnectToStation(LinkedStation);
		}
	}

	private void DropStation() {
		if (LinkedStation == null) {
			return;
		}

		LinkedStation.ToggleSelection(false);
		_spriteRenderer.sprite = nothingSprite;
		LinkedStation = null;
	}

	private void UseStation() {
		if (LinkedStation == null) {
			return;
		}

		LinkedStation.Use();
	}
}
