﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Station : MonoBehaviour {

	//A delegate is just a method signature, any method that returns a bool and takes an int is a FlipSwitch.
	public delegate bool FlipSwitch(int color);

	[Header("Sprites")]
	public Sprite[] sprites;

	public bool bStopOnFaultyLamp;

	private SpriteRenderer _spriteRenderer;

	event FlipSwitch myEvent;
	//This would work too for example.
	event System.Func<int, bool> myEvent2;

	SmartEvent<FlipSwitch> mySmartEvent = new SmartEvent<FlipSwitch>();

	void Awake() {
		_spriteRenderer = GetComponent<SpriteRenderer>();
	}

	public void ToggleSelection(bool bToggle) {
		transform.GetChild(0).gameObject.SetActive(bToggle);
	}

	public void Use() {
		if (!bStopOnFaultyLamp) {
			myEvent(GetNextColor());
		} else {
			bool bFaulty = false;
			foreach (FlipSwitch flip in mySmartEvent.Actions) {
				if (bFaulty) {
					flip(0);
				} else if (!flip(GetNextColor())) {
					bFaulty = true;
				}
			}
		}

		_spriteRenderer.sprite = sprites[GetNextColor()];
	}

	private int GetNextColor() {
		int i;

		for (i = 0; i < sprites.Length; i++) {
			if (_spriteRenderer.sprite == sprites[i]) {
				i++;
				if (i >= sprites.Length) {
					i = 0;
				}
				break;
			}
		}

		return i;
	}

	public void Connect(FlipSwitch nMethod) {
		if (!bStopOnFaultyLamp) {
			myEvent += nMethod;
		} else {
			mySmartEvent += nMethod;
		}
	}
}
